package com.example.android.preference;

import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.preference.CheckBoxPreference;
import android.preference.EditTextPreference;
import android.preference.ListPreference;
import android.preference.Preference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceCategory;
import android.preference.PreferenceScreen;
import android.preference.RingtonePreference;
import android.preference.Preference.OnPreferenceChangeListener;

public class Preferences2 extends PreferenceActivity {
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setPreferenceScreen(createPreferenceHierarchy());
		getPreferenceManager().findPreference("child_checkbox_preference").setDependency("parent_checkbox_preference");
	}
	
	private PreferenceScreen createPreferenceHierarchy() {
		// Root
		PreferenceScreen root = getPreferenceManager().createPreferenceScreen(this);

		// Ringtone
		RingtonePreference ringtonePref = new RingtonePreference(this);
		ringtonePref.setKey("ringtone_preference");
		ringtonePref.setTitle(R.string.ringtone_preference_title);
		ringtonePref.setSummary(R.string.ringtone_preference_summary);
		ringtonePref.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
			@Override
			public boolean onPreferenceChange(Preference preference, Object newValue) {
				((RingtonePreference)preference).setSummary(newValue.toString());
				return true;
			}
		});
		root.addPreference(ringtonePref);
		
		// Inline preferences
		PreferenceCategory inlinePrefCat = new PreferenceCategory(this);
		inlinePrefCat.setTitle(R.string.inline_preferences);
		root.addPreference(inlinePrefCat);

		// Toggle preference
		CheckBoxPreference togglePref = new CheckBoxPreference(this);
		togglePref.setKey("checkbox_preference");
		togglePref.setTitle(R.string.checkbox_preference_title);
		togglePref.setSummary(R.string.checkbox_preference_summary);
		togglePref.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
			@Override
			public boolean onPreferenceChange(Preference preference, Object newValue) {
				String summary;
				if (((Boolean)newValue).booleanValue()) {
					summary = "Selected";
				} else {
					summary = "Unselected";
				}
				((CheckBoxPreference)preference).setSummary(summary);
				return true;
			}
		});
		inlinePrefCat.addPreference(togglePref);

		// Dialog based preferences
		PreferenceCategory dialogBasedPrefCat = new PreferenceCategory(this);
		dialogBasedPrefCat.setTitle(R.string.dialog_based_preferences);
		root.addPreference(dialogBasedPrefCat);

		// Edit text preference
		EditTextPreference editTextPref = new EditTextPreference(this);
		editTextPref.setDialogTitle(R.string.edittext_preference_dialog_title);
		editTextPref.setKey("edittext_preference");
		editTextPref.setTitle(R.string.edittext_preference_title);
		editTextPref.setSummary(R.string.edittext_preference_summary);
		editTextPref.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
			@Override
			public boolean onPreferenceChange(Preference preference, Object newValue) {
				((EditTextPreference)preference).setSummary((String)newValue);
				return true;
			}
		});
		dialogBasedPrefCat.addPreference(editTextPref);

		// List preference
		ListPreference listPref = new ListPreference(this);
		listPref.setEntries(R.array.list_preference_entries);
		listPref.setEntryValues(R.array.list_preference_values);
		listPref.setDialogTitle(R.string.list_preference_dialog_title);
		listPref.setKey("list_preference");
		listPref.setTitle(R.string.list_preference_title);
		listPref.setSummary(R.string.list_preference_summary);
		listPref.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
			@Override
			public boolean onPreferenceChange(Preference preference, Object newValue) {
				String summary = "";
				String[] entries = getResources().getStringArray(R.array.list_preference_entries);
				String[] values = getResources().getStringArray(R.array.list_preference_values);
				for (int i = 0; i < values.length; ++i) {
					if (values[i].equals(newValue)) {
						summary = entries[i];
						break;
					}
				}
				((ListPreference)preference).setSummary(summary);
				return true;
			}
		});
		dialogBasedPrefCat.addPreference(listPref);

		// Launch preferences
		PreferenceCategory launchPrefCat = new PreferenceCategory(this);
		launchPrefCat.setTitle(R.string.launch_preferences);
		root.addPreference(launchPrefCat);

		/*
		 * The Preferences screenPref serves as a screen break (similar to page break in word processing). Like for
		 * other preference types, we assign a key here so that it is able to save and restore its instance state.
		 */
		// Screen preference
		PreferenceScreen screenPref2 = getPreferenceManager().createPreferenceScreen(this);
		screenPref2.setKey("screen_preference2");
		screenPref2.setTitle(R.string.screen_preference_title);
		screenPref2.setSummary(R.string.screen_preference_summary);
		launchPrefCat.addPreference(screenPref2);

		/*
		 * You can add more preferences to screenPref that will be shown on the next screen.
		 */

		// Example of next screen toggle preference
		CheckBoxPreference checkBoxPref2 = new CheckBoxPreference(this);
		checkBoxPref2.setKey("checkbox_preference2");
		checkBoxPref2.setTitle(R.string.checkbox_preference_title);
		checkBoxPref2.setSummary(R.string.checkbox_preference_summary);
		screenPref2.addPreference(checkBoxPref2);

		PreferenceScreen screenPref3 = getPreferenceManager().createPreferenceScreen(this);
		screenPref3.setKey("screen_preference2");
		screenPref3.setTitle(R.string.screen_preference_title);
		screenPref3.setSummary(R.string.screen_preference_summary);
		screenPref2.addPreference(screenPref3);

		CheckBoxPreference checkBoxPref3 = new CheckBoxPreference(this);
		checkBoxPref3.setKey("checkbox_preference3");
		checkBoxPref3.setTitle(R.string.checkbox_preference_title);
		checkBoxPref3.setSummary(R.string.checkbox_preference_summary);
		screenPref3.addPreference(checkBoxPref3);

		// Intent preference
		PreferenceScreen intentPref = getPreferenceManager().createPreferenceScreen(this);
		intentPref.setIntent(new Intent().setAction(Intent.ACTION_VIEW).setData(Uri.parse("http://www.atmarkit.co.jp")));
		intentPref.setTitle(R.string.intent_preference_title);
		intentPref.setSummary(R.string.intent_preference_summary);
		launchPrefCat.addPreference(intentPref);

		// Preference attributes
		PreferenceCategory prefAttrsCat = new PreferenceCategory(this);
		prefAttrsCat.setTitle(R.string.preference_attributes);
		root.addPreference(prefAttrsCat);

		// Visual parent toggle preference
		CheckBoxPreference parentCheckBoxPref = new CheckBoxPreference(this);
		parentCheckBoxPref.setKey("parent_checkbox_preference");
		parentCheckBoxPref.setTitle(R.string.parent_preference_title);
		parentCheckBoxPref.setSummary(R.string.parent_preference_summary);
		prefAttrsCat.addPreference(parentCheckBoxPref);

		// Visual child toggle preference
		// See res/values/attrs.xml for the <declare-styleable> that defines
		// TogglePrefAttrs.
		CheckBoxPreference childCheckBoxPref = new CheckBoxPreference(this) {
			@Override
			public void onDependencyChanged(Preference dependency, boolean disableDependent) {
				setEnabled(!disableDependent);
			}
		};
		childCheckBoxPref.setKey("child_checkbox_preference");
		childCheckBoxPref.setTitle(R.string.child_preference_title);
		childCheckBoxPref.setSummary(R.string.child_preference_summary);
		prefAttrsCat.addPreference(childCheckBoxPref);

		return root;
	}
}
